#
# spec file for package python3-Pillow
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Pillow
Version:        2.9.0
Release:        4.1
Summary:        Python Imaging Library (Fork)
License:        HPND
Group:          Development/Languages/Python
Url:            http://python-pillow.github.io/
Source:         https://pypi.python.org/packages/source/P/Pillow/Pillow-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-tk
BuildRequires:  tix
BuildRequires:  tk-devel
BuildRequires:  unzip
%if 0%{?suse_version} > 1210
BuildRequires:  libjpeg8-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libwebp-devel
%endif
%if 0%{?suse_version} > 1315
BuildRequires:  openjpeg2-devel
%endif
BuildRequires:  freetype2-devel
BuildRequires:  libtiff-devel
BuildRequires:  python3-nose
BuildRequires:  zlib-devel
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Pillow is the "friendly" PIL fork by Alex Clark and Contributors. PIL is the
Python Imaging Library by Fredrik Lundh and Contributors.

%package tk
Summary:        Python Imaging Library (Fork) - Tcl/Tk Module
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description tk
Pillow is the "friendly" PIL fork by Alex Clark and Contributors. PIL is the
Python Imaging Library by Fredrik Lundh and Contributors.

%prep
%setup -q -n Pillow-%{version}

%build
# no need to build it here, as setup.py install will build it again, anyway

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for p in pilconvert pildriver pilfile pilfont pilprint ; do
  mv %{buildroot}%{_bindir}/$p.py %{buildroot}%{_bindir}/$p-%{py3_ver}
  ln -s %{_bindir}/$p-%{py3_ver} %{buildroot}%{_bindir}/$p
  ln -s %{_bindir}/$p-%{py3_ver} %{buildroot}%{_sysconfdir}/alternatives/$p
done

%check
PYTHONPATH=%{buildroot}/%{python3_sitearch} python3 selftest.py --installed
PYTHONPATH=%{buildroot}/%{python3_sitearch} python3 test-installed.py

%post
update-alternatives \
    --install %{_bindir}/pilconvert pilconvert %{_bindir}/pilconvert-%{py3_ver} 30 \
    --slave %{_bindir}/pildriver pildriver %{_bindir}/pildriver-%{py3_ver} \
    --slave %{_bindir}/pilfile pilfile %{_bindir}/pilfile-%{py3_ver} \
    --slave %{_bindir}/pilfont pilfont %{_bindir}/pilfont-%{py3_ver} \
    --slave %{_bindir}/pilprint pilprint %{_bindir}/pilprint-%{py3_ver}

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove pilconvert %{_bindir}/pilconvert-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc CHANGES.rst README.rst
%ghost %{_bindir}/pilconvert
%{_bindir}/pilconvert-%{py3_ver}
%ghost %{_bindir}/pildriver
%{_bindir}/pildriver-%{py3_ver}
%ghost %{_bindir}/pilfile
%{_bindir}/pilfile-%{py3_ver}
%ghost %{_bindir}/pilfont
%{_bindir}/pilfont-%{py3_ver}
%ghost %{_bindir}/pilprint
%{_bindir}/pilprint-%{py3_ver}
%{python3_sitearch}/PIL
%{python3_sitearch}/Pillow-%{version}-py%{py3_ver}.egg-info
%if 0%{?suse_version} != 1315
%exclude %{python3_sitearch}/PIL/ImageTk*
%exclude %{python3_sitearch}/PIL/_imagingtk*
%exclude %{python3_sitearch}/PIL/__pycache__/ImageTk.*.pyc
%endif
%if 0%{?suse_version} > 1210
%ghost %{_sysconfdir}/alternatives/pilconvert
%ghost %{_sysconfdir}/alternatives/pildriver
%ghost %{_sysconfdir}/alternatives/pilfile
%ghost %{_sysconfdir}/alternatives/pilfont
%ghost %{_sysconfdir}/alternatives/pilprint
%endif

%if 0%{?suse_version} != 1315
%files tk
%defattr(-,root,root,-)
%{python3_sitearch}/PIL/ImageTk*
%{python3_sitearch}/PIL/_imagingtk*
%{python3_sitearch}/PIL/__pycache__/ImageTk.*.pyc
%endif

%changelog
* Sat Sep  5 2015 badshah400@gmail.com
- For openSUSE:42 do not use %%exclude on packages which are not
  being packaged elsewhere anyway; fixes build failures caused
  due to unpackaged debuginfo files generated otherwise.
* Mon Jul 13 2015 arun@gmx.de
- update to version 2.9.0:
  * Added test for GimpPaletteFile #1324 [radarhere]
  * Fixed ValueError in Python 2.6 #1315 #1316 [cgohlke, radarhere]
  * Fixed tox test script path #1308 [radarhere]
  * Added width and height properties #1304 [radarhere]
  * Update tiff and tk tcl 8.5 versions #1303 [radarhere, wiredfool]
  * Add functions to convert: Image <-> QImage; Image <-> QPixmap
    [#1217] [radarhere, rominf]
  * Remove duplicate code in gifmaker script #1294 [radarhere]
  * Multiline text in ImageDraw #1177 [allo-, radarhere]
  * Automated Windows CI/build support #1278 [wiredfool]
  * Removed support for Tk versions earlier than 8.4 #1288 [radarhere]
  * Fixed polygon edge drawing #1255 (fixes #1252) [radarhere]
  * Check prefix length in _accept methods #1267 [radarhere]
  * Register MIME type for BMP #1277 [coldmind]
  * Adjusted ImageQt use of unicode() for 2/3 compatibility #1218
    [radarhere]
  * Identify XBM file created with filename including underscore #1230
    (fixes #1229) [hugovk]
  * Copy image when saving in GifImagePlugin #1231 (fixes #718)
    [radarhere]
  * Removed support for FreeType 2.0 #1247 [radarhere]
  * Added background saving to GifImagePlugin #1273 [radarhere]
  * Provide n_frames attribute to multi-frame formats #1261 [anntzer,
    radarhere]
  * Add duration and loop set to GifImagePlugin #1172, #1269
    [radarhere]
  * Ico files are little endian #1232 [wiredfool]
  * Upgrade olefile from 0.30 to 0.42b #1226 [radarhere, decalage2]
  * Setting transparency value to 0 when the tRNS contains only null
    byte(s) #1239 [juztin]
  * Separated out feature checking from selftest #1233 [radarhere]
  * Style/health fixes [radarhere]
  * Update WebP from 0.4.1 to 0.4.3 #1235 [radarhere]
  * Release GIL during image load (decode) #1224 [lkesteloot]
  * Added icns save #1185 [radarhere]
  * Fix putdata memory leak #1196 [benoit-pierre]
  * Keep user-specified ordering of icon sizes #1193 [karimbahgat]
  * Tiff: allow writing floating point tag values #1113 [bpedersen2]
* Mon Jun 29 2015 toddrme2178@gmail.com
- Disable tk in SLES 12
* Sat Jun 13 2015 arun@gmx.de
- update to version 2.8.2:
  * Bug fix: Fixed Tiff handling of bad EXIF data [radarhere]
* Fri Apr  3 2015 arun@gmx.de
- update to version 2.8.1:
  * Bug fix: Catch struct.error on invalid JPEG, fixes #1163 [wiredfool, hugovk]
- changes from version 2.8.0:
  * Fix 32-bit BMP loading (RGBA or RGBX) [artscoop]
  * Fix UnboundLocalError in ImageFile #1131 [davarisg]
  * Re-enable test image caching [hugovk, homm]
  * Fix: Cannot identify EPS images, fixes #1104 [hugovk]
  * Configure setuptools to run nosetests, fixes #729 [aclark4life]
  * Style/health fixes [radarhere, hugovk]
  * Add support for HTTP response objects to Image.open() [mfitzp]
  * Improve reference docs for PIL.ImageDraw.Draw.pieslice() #1145
    [audreyr]
  * Added copy method font_variant() and accessible properties to
    truetype() #1123 [radarhere]
  * Fix ImagingEffectNoise #1128 [hugovk]
  * Remove unreachable code [hugovk]
  * Let Python do the endian stuff + tests #1121 [amoibos, radarhere]
  * Fix webp decode memory leak #1114 [benoit-pierre]
  * Fast path for opaque pixels in RGBa unpacker #1088 [bgilbert]
  * Enable basic support for 'RGBa' raw encoding/decoding #1096
    [immerrr]
  * Fix pickling L mode images with no palette, #1095 [hugovk]
  * iPython display hook #1091 [wiredfool]
  * Adjust buffer size when quality=keep, fixes #148 (again)
    [wiredfool]
  * Fix for corrupted bitmaps embedded in truetype fonts. #1072
    [jackyyf, wiredfool]
* Sun Jan  4 2015 arun@gmx.de
- specfile:
  * update copyright year
  * update home page
- update to version 2.7.0:
  * Split Sane into a separate repo: https://github.com/python-pillow/Sane [hugovk]
  * Look for OSX and Linux fonts in common places. #1054 [charleslaw]
  * Fix potential PNG decompression DOS #1060 [wiredfool]
  * Use underscores, not spaces, in TIFF tag kwargs. #1044, #1058 [anntzer, hugovk]
  * Update PSDraw for Python3, add tests. #1055 [hugovk]
  * Use Bicubic filtering by default for thumbnails. Don't use Jpeg Draft mode for thumbnails. #1029 [homm]
  * Fix MSVC compiler error: Use Py_ssize_t instead of ssize_t #1051 [cgohlke]
  * Fix compiler error: MSVC needs varaibles defined at the start of the block #1048 [cgohlke]
  * The GIF Palette optimization algorithm is only applicable to mode='P' or 'L' #993 [moriyoshi]
  * Use PySide as an alternative to PyQt4/5. [holg]
  * Replace affine-based im.resize implementation with convolution-based im.stretch #997 [homm]
  * Replace Gaussian Blur implementation with iterated fast box
    blur. #961 Note: Radius parameter is interpreted differently than
    before. [hommBetter docs explaining import _imaging failure #1016,
    build #1017, mode #1018, PyAccess, PixelAccess objects #1019
    Image.quantize #1020 and Image.save #1021 [wiredfool]
  * Fix for saving TIFF image into an io.BytesIO buffer #1011 [mfergie]
  * Fix antialias compilation on debug versions of Python #1010 [wiredfool]
  * Fix for Image.putdata segfault #1009 [wiredfool]
  * Ico save, additional tests #1007 [exherb]
  * Use PyQt4 if it has already been imported, otherwise prefer PyQt5. #1003 [AurelienBallier]
  * Speedup resample implementation up to 2.5 times. #977 [homm]
  * Speed up rotation by using cache aware loops, added transpose to rotations. #994 [homm]
  * Fix Bicubic interpolation #970 [homm]
  * Support for 4-bit greyscale TIFF images #980 [hugovk]
  * Updated manifest #957 [wiredfool]
  * Fix PyPy 2.4 regression #952 [wiredfool]
  * Webp Metadata Skip Test comments #954 [wiredfool]
  * Fixes for things rpmlint complains about #942 [manisandro]
- changes from version 2.6.2:
  * Fix potential PNG decompression DOS #1060 [wiredfool]
  * Fix Regression in PyPy 2.4 in streamio #958 [wiredfool]
* Tue Nov 18 2014 toddrme2178@gmail.com
- Update to 2.6.1
  - Fix SciPy regression for in Image.resize
  - Fix manifest to include all test files
- Update to 2.6.0
  - Relax precision of ImageDraw tests for x86, GimpGradient for PPC
  - Use redistributable image for testing
  - Use redistributable ICC profiles for testing, skip if not available
  - Additional documentation for JPEG info and save options
  - Fix JPEG Encoding memory leak when exif or qtables were specified
  - Image.tobytes() and Image.tostring() documentation update
  - On Windows, do not execute convert.exe without specifying path
  - Fix msvc build error
  - Fix for handling P + transparency -> RGBA conversions
  - Retain alpha in ImageEnhance operations
  - Jpeg2k Decode/encode memory leak fix
  - EpsFilePlugin Speed improvements
  - Don't resize if already the right size
  - Fix for reading multipage TIFFs
  - Correctly handle saving gray and CMYK JPEGs with quality=keep
  - Correct duplicate Tiff Metadata and Exif tag values
  - Windows fixes
  - Fix TGA files with image ID field
  - Fixed wrong P-mode of small, unoptimized L-mode GIF
  - Fixed CVE-2014-3598, a DOS in the Jpeg2KImagePlugin
  - Fixed CVE-2014-3589, a DOS in the IcnsImagePlugin
  - setup.py: Close open file handle before deleting
  - Return Profile with Transformed Images
  - Changed docstring to refer to the correct function
  - Adding coverage support for C code tests
  - PyPy performance improvements
  - Added support for reading MPO files
  - Added support for encoding and decoding iTXt chunks
  - HSV Support
  - Removed unusable ImagePalette.new()
  - Fix Scrambled XPM
  - Doc cleanup
  - Fix `ImageStat` docs
  - Added docs for ExifTags
  - More tests for CurImagePlugin, DcxImagePlugin, Effects.c, GimpGradientFile, ImageFont, ImageMath, ImagePalette, IptcImagePlugin, SpiderImagePlugin, SgiImagePlugin, XpmImagePlugin and _util
  - Fix return value of FreeTypeFont.textsize() does not include font offsets
  - Fix dispose calculations for animated GIFs
  - Added class checking to Image __eq__ function
  - Test PalmImagePlugin and method to skip known bad tests
- Update to 2.5.3
  - Fixed CVE-2014-3598, a DOS in the Jpeg2KImagePlugin (backport)
- Update to 2.5.2
  - Fixed CVE-2014-3589, a DOS in the IcnsImagePlugin (backport)
- Update to 2.5.1:
  * 2.5.1 (2014-07-10)
    Fixed install issue if Multiprocessing.Pool is not available [wiredfool]
    32bit mult overflow fix #782 [wiredfool]
  * 2.5.0 (2014-07-01)
    Imagedraw rewrite [terseus, wiredfool]
    Add support for multithreaded test execution [wiredfool]
    Prevent shell injection #748 [mbrown1413, wiredfool]
    Support for Resolution in BMP files #734 [gcq]
    Fix error in setup.py for Python 3 [matthew-brett]
    Pyroma fix and add Python 3.4 to setup metadata #742 [wirefool]
    Top level flake8 fixes #741 [aclark]
    Remove obsolete Animated Raster Graphics (ARG) support [hugovk]
    Fix test_imagedraw failures #727 [cgohlke]
    Fix AttributeError: class Image has no attribute 'DEBUG' #726 [cgohlke]
    Fix msvc warning: 'inline' : macro redefinition #725 [cgohlke]
    Cleanup #654 [dvska, hugovk, wiredfool]
    16-bit monochrome support for JPEG2000 [videan42]
    Fixed ImagePalette.save [brightpisces]
    Support JPEG qtables [csinchok]
    Add binary morphology addon [dov, wiredfool]
    Decompression bomb protection [hugovk]
    Put images in a single directory [hugovk]
    Support OpenJpeg 2.1 [al45tair]
    Remove unistd.h #include for all platforms [wiredfool]
    Use unittest for tests [hugovk]
    ImageCms fixes [hugovk]
    Added more ImageDraw tests [hugovk]
    Added tests for Spider files [hugovk]
    Use libtiff to write any compressed tiff files [wiredfool]
    Support for pickling Image objects [hugovk]
    Fixed resolution handling for EPS thumbnails [eliempje]
    Fixed rendering of some binary EPS files (Issue #302) [eliempje]
    Rename variables not to use built-in function names [hugovk]
    Ignore junk JPEG markers [hugovk]
    Change default interpolation for Image.thumbnail to Image.ANTIALIAS [hugovk]
    Add tests and fixes for saving PDFs [hugovk]
    Remove transparency resource after P->RGBA conversion [hugovk]
    Clean up preprocessor cruft for Windows [CounterPillow]
    Adjust Homebrew freetype detection logic [jacknagel]
    Added Image.close, context manager support. [wiredfool]
    Added support for 16 bit PGM files. [wiredfool]
    Updated OleFileIO to version 0.30 from upstream [hugovk]
    Added support for additional TIFF floating point format [Hijackal]
    Have the tempfile use a suffix with a dot [wiredfool]
    Fix variable name used for transparency manipulations [nijel]
- adjusted testsuite execution
* Thu May  8 2014 toddrme2178@gmail.com
- New upstream release 2.4.0. For details see
  https://pypi.python.org/pypi/Pillow/2.4.0
- New upstream release 2.3.0. For details see
  https://pypi.python.org/pypi/Pillow/2.3.0
- symlink alternatives files, as requested from Coolo, in order to
  get rid of suse version conditional
- Drop use-recommended-freetype-include.patch: merged on upstream
- Build with liblcms2 instead of liblcms due to upstream switching
  library.
* Mon Dec 16 2013 hrvoje.senjan@gmail.com
- Added use-recommended-freetype-include.patch -- Freetype upstream
  recommends using their macros together with ft2build include.
  Positive sideeffect is that this patch makes it build with both
  freetype2 2.5.1, and older version
* Wed Dec 11 2013 speilicke@suse.com
- Move TkImage.pyc file to sub-package
* Mon Nov 18 2013 speilicke@suse.com
- Move away from pkgconfig-style buildrequires to support SLE
- Implement update-alternatives
* Thu Nov 14 2013 cfarrell@suse.com
- License update: HPND
* Tue Nov 12 2013 speilicke@suse.com
- Add split-provides inside tk sub-package to get rid of python-imaging-tk
* Thu Nov  7 2013 speilicke@suse.com
- Initial version
